@@ -102,9 +102,14 @@ slickR <- function( obj ,
                               with = "slickR::settings()")
   }
   
+  checkmate::checkCharacter(height, null.ok = TRUE)
+  checkmate::checkCharacter(width, null.ok = TRUE)
+  
   if(is.null(height))
     height <- sprintf("%s%%",100 - padding)
   
+  
+  
   # If obj is not already DOM then convert to it
   
   if(!inherits(obj,'shiny.tag.list')){
@@ -159,31 +164,3 @@ slickR <- function( obj ,
   )
 
 }
-
-#' Shiny bindings for slickR
-#'
-#' Output and render functions for using slickR within Shiny
-#' applications and interactive Rmd documents.
-#'
-#' @param outputId output variable to read from
-#' @param width,height Must be a valid CSS unit (like \code{'100\%'},
-#'   \code{'400px'}, \code{'auto'}) or a number, which will be coerced to a
-#'   string and have \code{'px'} appended.
-#' @param expr An expression that generates a slickR
-#' @param env The environment in which to evaluate \code{expr}.
-#' @param quoted Is \code{expr} a quoted expression (with \code{quote()})? This
-#'   is useful if you want to save an expression in a variable.
-#'
-#' @name slickR-shiny
-#'
-#' @export
-slickROutput <- function(outputId, width = '100%', height = '400px'){
-  htmlwidgets::shinyWidgetOutput(outputId, 'slickR', width, height, package = 'slickR')
-}
-
-#' @rdname slickR-shiny
-#' @export
-renderSlickR <- function(expr, env = parent.frame(), quoted = FALSE) {
-  if (!quoted) { expr <- substitute(expr) } # force quoted
-  htmlwidgets::shinyRenderWidget(expr, slickROutput, env, quoted = TRUE)
-}
\ No newline at end of file
